# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: auth.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biostarPython.service import err_pb2 as err__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='auth.proto',
  package='auth',
  syntax='proto3',
  serialized_options=_b('\n\027com.supremainc.sdk.authP\001Z\024biostar/service/auth'),
  serialized_pb=_b('\n\nauth.proto\x12\x04\x61uth\x1a\terr.proto\">\n\x08Operator\x12\x0e\n\x06userID\x18\x01 \x01(\t\x12\"\n\x05level\x18\x02 \x01(\x0e\x32\x13.auth.OperatorLevel\"@\n\x0c\x41uthSchedule\x12\x1c\n\x04mode\x18\x01 \x01(\x0e\x32\x0e.auth.AuthMode\x12\x12\n\nscheduleID\x18\x02 \x01(\r\"\xf1\x02\n\nAuthConfig\x12)\n\rauthSchedules\x18\x01 \x03(\x0b\x32\x12.auth.AuthSchedule\x12\x14\n\x0cuseGlobalAPB\x18\x02 \x01(\x08\x12:\n\x13globalAPBFailAction\x18\x03 \x01(\x0e\x32\x1d.auth.GlobalAPBFailActionType\x12\x18\n\x10useGroupMatching\x18\x04 \x01(\x08\x12\x16\n\x0eusePrivateAuth\x18\x05 \x01(\x08\x12\x34\n\x12\x66\x61\x63\x65\x44\x65tectionLevel\x18\x06 \x01(\x0e\x32\x18.auth.FaceDetectionLevel\x12\x19\n\x11useServerMatching\x18\x07 \x01(\x08\x12\x15\n\ruseFullAccess\x18\x08 \x01(\x08\x12\x14\n\x0cmatchTimeout\x18\t \x01(\r\x12\x13\n\x0b\x61uthTimeout\x18\n \x01(\r\x12!\n\toperators\x18\x0b \x03(\x0b\x32\x0e.auth.Operator\"$\n\x10GetConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"5\n\x11GetConfigResponse\x12 \n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x10.auth.AuthConfig\"F\n\x10SetConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12 \n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x10.auth.AuthConfig\"\x13\n\x11SetConfigResponse\"L\n\x15SetConfigMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12 \n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x10.auth.AuthConfig\"B\n\x16SetConfigMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse*\xdb\x0e\n\x08\x41uthMode\x12\x1c\n\x18\x41UTH_MODE_BIOMETRIC_ONLY\x10\x00\x12\x1b\n\x17\x41UTH_MODE_BIOMETRIC_PIN\x10\x01\x12\x17\n\x13\x41UTH_MODE_CARD_ONLY\x10\x02\x12\x1c\n\x18\x41UTH_MODE_CARD_BIOMETRIC\x10\x03\x12\x16\n\x12\x41UTH_MODE_CARD_PIN\x10\x04\x12#\n\x1f\x41UTH_MODE_CARD_BIOMETRIC_OR_PIN\x10\x05\x12 \n\x1c\x41UTH_MODE_CARD_BIOMETRIC_PIN\x10\x06\x12\x1a\n\x16\x41UTH_MODE_ID_BIOMETRIC\x10\x07\x12\x14\n\x10\x41UTH_MODE_ID_PIN\x10\x08\x12!\n\x1d\x41UTH_MODE_ID_BIOMETRIC_OR_PIN\x10\t\x12\x1e\n\x1a\x41UTH_MODE_ID_BIOMETRIC_PIN\x10\n\x12\x13\n\x0e\x41UTH_MODE_NONE\x10\xff\x01\x12\x19\n\x14\x41UTH_MODE_PROHIBITED\x10\xfe\x01\x12\x1b\n\x17\x41UTH_EXT_MODE_FACE_ONLY\x10\x0b\x12\"\n\x1e\x41UTH_EXT_MODE_FACE_FINGERPRINT\x10\x0c\x12\x1a\n\x16\x41UTH_EXT_MODE_FACE_PIN\x10\r\x12)\n%AUTH_EXT_MODE_FACE_FINGERPRINT_OR_PIN\x10\x0e\x12&\n\"AUTH_EXT_MODE_FACE_FINGERPRINT_PIN\x10\x0f\x12\"\n\x1e\x41UTH_EXT_MODE_FINGERPRINT_ONLY\x10\x10\x12\"\n\x1e\x41UTH_EXT_MODE_FINGERPRINT_FACE\x10\x11\x12!\n\x1d\x41UTH_EXT_MODE_FINGERPRINT_PIN\x10\x12\x12)\n%AUTH_EXT_MODE_FINGERPRINT_FACE_OR_PIN\x10\x13\x12&\n\"AUTH_EXT_MODE_FINGERPRINT_FACE_PIN\x10\x14\x12\x1b\n\x17\x41UTH_EXT_MODE_CARD_ONLY\x10\x15\x12\x1b\n\x17\x41UTH_EXT_MODE_CARD_FACE\x10\x16\x12\"\n\x1e\x41UTH_EXT_MODE_CARD_FINGERPRINT\x10\x17\x12\x1a\n\x16\x41UTH_EXT_MODE_CARD_PIN\x10\x18\x12*\n&AUTH_EXT_MODE_CARD_FACE_OR_FINGERPRINT\x10\x19\x12\"\n\x1e\x41UTH_EXT_MODE_CARD_FACE_OR_PIN\x10\x1a\x12)\n%AUTH_EXT_MODE_CARD_FINGERPRINT_OR_PIN\x10\x1b\x12\x31\n-AUTH_EXT_MODE_CARD_FACE_OR_FINGERPRINT_OR_PIN\x10\x1c\x12\'\n#AUTH_EXT_MODE_CARD_FACE_FINGERPRINT\x10\x1d\x12\x1f\n\x1b\x41UTH_EXT_MODE_CARD_FACE_PIN\x10\x1e\x12\'\n#AUTH_EXT_MODE_CARD_FINGERPRINT_FACE\x10\x1f\x12&\n\"AUTH_EXT_MODE_CARD_FINGERPRINT_PIN\x10 \x12.\n*AUTH_EXT_MODE_CARD_FACE_OR_FINGERPRINT_PIN\x10!\x12.\n*AUTH_EXT_MODE_CARD_FACE_FINGERPRINT_OR_PIN\x10\"\x12.\n*AUTH_EXT_MODE_CARD_FINGERPRINT_FACE_OR_PIN\x10#\x12\x19\n\x15\x41UTH_EXT_MODE_ID_FACE\x10$\x12 \n\x1c\x41UTH_EXT_MODE_ID_FINGERPRINT\x10%\x12\x18\n\x14\x41UTH_EXT_MODE_ID_PIN\x10&\x12(\n$AUTH_EXT_MODE_ID_FACE_OR_FINGERPRINT\x10\'\x12 \n\x1c\x41UTH_EXT_MODE_ID_FACE_OR_PIN\x10(\x12\'\n#AUTH_EXT_MODE_ID_FINGERPRINT_OR_PIN\x10)\x12/\n+AUTH_EXT_MODE_ID_FACE_OR_FINGERPRINT_OR_PIN\x10*\x12%\n!AUTH_EXT_MODE_ID_FACE_FINGERPRINT\x10+\x12\x1d\n\x19\x41UTH_EXT_MODE_ID_FACE_PIN\x10,\x12%\n!AUTH_EXT_MODE_ID_FINGERPRINT_FACE\x10-\x12$\n AUTH_EXT_MODE_ID_FINGERPRINT_PIN\x10.\x12,\n(AUTH_EXT_MODE_ID_FACE_OR_FINGERPRINT_PIN\x10/\x12,\n(AUTH_EXT_MODE_ID_FACE_FINGERPRINT_OR_PIN\x10\x30\x12,\n(AUTH_EXT_MODE_ID_FINGERPRINT_FACE_OR_PIN\x10\x31*v\n\rOperatorLevel\x12\x17\n\x13OPERATOR_LEVEL_NONE\x10\x00\x12\x18\n\x14OPERATOR_LEVEL_ADMIN\x10\x01\x12\x19\n\x15OPERATOR_LEVEL_CONFIG\x10\x02\x12\x17\n\x13OPERATOR_LEVEL_USER\x10\x03*c\n\x12\x46\x61\x63\x65\x44\x65tectionLevel\x12\x17\n\x13\x46\x41\x43\x45_DETECTION_NONE\x10\x00\x12\x19\n\x15\x46\x41\x43\x45_DETECTION_NORMAL\x10\x01\x12\x19\n\x15\x46\x41\x43\x45_DETECTION_STRICT\x10\x02*|\n\x17GlobalAPBFailActionType\x12\x1f\n\x1bGLOBAL_APB_FAIL_ACTION_NONE\x10\x00\x12\x1f\n\x1bGLOBAL_APB_FAIL_ACTION_SOFT\x10\x01\x12\x1f\n\x1bGLOBAL_APB_FAIL_ACTION_HARD\x10\x02\x32\xcf\x01\n\x04\x41uth\x12<\n\tGetConfig\x12\x16.auth.GetConfigRequest\x1a\x17.auth.GetConfigResponse\x12<\n\tSetConfig\x12\x16.auth.SetConfigRequest\x1a\x17.auth.SetConfigResponse\x12K\n\x0eSetConfigMulti\x12\x1b.auth.SetConfigMultiRequest\x1a\x1c.auth.SetConfigMultiResponseB1\n\x17\x63om.supremainc.sdk.authP\x01Z\x14\x62iostar/service/authb\x06proto3')
  ,
  dependencies=[err__pb2.DESCRIPTOR,])

_AUTHMODE = _descriptor.EnumDescriptor(
  name='AuthMode',
  full_name='auth.AuthMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUTH_MODE_BIOMETRIC_ONLY', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_MODE_BIOMETRIC_PIN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_MODE_CARD_ONLY', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_MODE_CARD_BIOMETRIC', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_MODE_CARD_PIN', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_MODE_CARD_BIOMETRIC_OR_PIN', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_MODE_CARD_BIOMETRIC_PIN', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_MODE_ID_BIOMETRIC', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_MODE_ID_PIN', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_MODE_ID_BIOMETRIC_OR_PIN', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_MODE_ID_BIOMETRIC_PIN', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_MODE_NONE', index=11, number=255,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_MODE_PROHIBITED', index=12, number=254,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_FACE_ONLY', index=13, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_FACE_FINGERPRINT', index=14, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_FACE_PIN', index=15, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_FACE_FINGERPRINT_OR_PIN', index=16, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_FACE_FINGERPRINT_PIN', index=17, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_FINGERPRINT_ONLY', index=18, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_FINGERPRINT_FACE', index=19, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_FINGERPRINT_PIN', index=20, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_FINGERPRINT_FACE_OR_PIN', index=21, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_FINGERPRINT_FACE_PIN', index=22, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_CARD_ONLY', index=23, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_CARD_FACE', index=24, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_CARD_FINGERPRINT', index=25, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_CARD_PIN', index=26, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_CARD_FACE_OR_FINGERPRINT', index=27, number=25,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_CARD_FACE_OR_PIN', index=28, number=26,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_CARD_FINGERPRINT_OR_PIN', index=29, number=27,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_CARD_FACE_OR_FINGERPRINT_OR_PIN', index=30, number=28,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_CARD_FACE_FINGERPRINT', index=31, number=29,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_CARD_FACE_PIN', index=32, number=30,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_CARD_FINGERPRINT_FACE', index=33, number=31,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_CARD_FINGERPRINT_PIN', index=34, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_CARD_FACE_OR_FINGERPRINT_PIN', index=35, number=33,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_CARD_FACE_FINGERPRINT_OR_PIN', index=36, number=34,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_CARD_FINGERPRINT_FACE_OR_PIN', index=37, number=35,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_ID_FACE', index=38, number=36,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_ID_FINGERPRINT', index=39, number=37,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_ID_PIN', index=40, number=38,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_ID_FACE_OR_FINGERPRINT', index=41, number=39,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_ID_FACE_OR_PIN', index=42, number=40,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_ID_FINGERPRINT_OR_PIN', index=43, number=41,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_ID_FACE_OR_FINGERPRINT_OR_PIN', index=44, number=42,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_ID_FACE_FINGERPRINT', index=45, number=43,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_ID_FACE_PIN', index=46, number=44,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_ID_FINGERPRINT_FACE', index=47, number=45,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_ID_FINGERPRINT_PIN', index=48, number=46,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_ID_FACE_OR_FINGERPRINT_PIN', index=49, number=47,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_ID_FACE_FINGERPRINT_OR_PIN', index=50, number=48,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_EXT_MODE_ID_FINGERPRINT_FACE_OR_PIN', index=51, number=49,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=866,
  serialized_end=2749,
)
_sym_db.RegisterEnumDescriptor(_AUTHMODE)

AuthMode = enum_type_wrapper.EnumTypeWrapper(_AUTHMODE)
_OPERATORLEVEL = _descriptor.EnumDescriptor(
  name='OperatorLevel',
  full_name='auth.OperatorLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OPERATOR_LEVEL_NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OPERATOR_LEVEL_ADMIN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OPERATOR_LEVEL_CONFIG', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OPERATOR_LEVEL_USER', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2751,
  serialized_end=2869,
)
_sym_db.RegisterEnumDescriptor(_OPERATORLEVEL)

OperatorLevel = enum_type_wrapper.EnumTypeWrapper(_OPERATORLEVEL)
_FACEDETECTIONLEVEL = _descriptor.EnumDescriptor(
  name='FaceDetectionLevel',
  full_name='auth.FaceDetectionLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FACE_DETECTION_NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FACE_DETECTION_NORMAL', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FACE_DETECTION_STRICT', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2871,
  serialized_end=2970,
)
_sym_db.RegisterEnumDescriptor(_FACEDETECTIONLEVEL)

FaceDetectionLevel = enum_type_wrapper.EnumTypeWrapper(_FACEDETECTIONLEVEL)
_GLOBALAPBFAILACTIONTYPE = _descriptor.EnumDescriptor(
  name='GlobalAPBFailActionType',
  full_name='auth.GlobalAPBFailActionType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GLOBAL_APB_FAIL_ACTION_NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GLOBAL_APB_FAIL_ACTION_SOFT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GLOBAL_APB_FAIL_ACTION_HARD', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2972,
  serialized_end=3096,
)
_sym_db.RegisterEnumDescriptor(_GLOBALAPBFAILACTIONTYPE)

GlobalAPBFailActionType = enum_type_wrapper.EnumTypeWrapper(_GLOBALAPBFAILACTIONTYPE)
AUTH_MODE_BIOMETRIC_ONLY = 0
AUTH_MODE_BIOMETRIC_PIN = 1
AUTH_MODE_CARD_ONLY = 2
AUTH_MODE_CARD_BIOMETRIC = 3
AUTH_MODE_CARD_PIN = 4
AUTH_MODE_CARD_BIOMETRIC_OR_PIN = 5
AUTH_MODE_CARD_BIOMETRIC_PIN = 6
AUTH_MODE_ID_BIOMETRIC = 7
AUTH_MODE_ID_PIN = 8
AUTH_MODE_ID_BIOMETRIC_OR_PIN = 9
AUTH_MODE_ID_BIOMETRIC_PIN = 10
AUTH_MODE_NONE = 255
AUTH_MODE_PROHIBITED = 254
AUTH_EXT_MODE_FACE_ONLY = 11
AUTH_EXT_MODE_FACE_FINGERPRINT = 12
AUTH_EXT_MODE_FACE_PIN = 13
AUTH_EXT_MODE_FACE_FINGERPRINT_OR_PIN = 14
AUTH_EXT_MODE_FACE_FINGERPRINT_PIN = 15
AUTH_EXT_MODE_FINGERPRINT_ONLY = 16
AUTH_EXT_MODE_FINGERPRINT_FACE = 17
AUTH_EXT_MODE_FINGERPRINT_PIN = 18
AUTH_EXT_MODE_FINGERPRINT_FACE_OR_PIN = 19
AUTH_EXT_MODE_FINGERPRINT_FACE_PIN = 20
AUTH_EXT_MODE_CARD_ONLY = 21
AUTH_EXT_MODE_CARD_FACE = 22
AUTH_EXT_MODE_CARD_FINGERPRINT = 23
AUTH_EXT_MODE_CARD_PIN = 24
AUTH_EXT_MODE_CARD_FACE_OR_FINGERPRINT = 25
AUTH_EXT_MODE_CARD_FACE_OR_PIN = 26
AUTH_EXT_MODE_CARD_FINGERPRINT_OR_PIN = 27
AUTH_EXT_MODE_CARD_FACE_OR_FINGERPRINT_OR_PIN = 28
AUTH_EXT_MODE_CARD_FACE_FINGERPRINT = 29
AUTH_EXT_MODE_CARD_FACE_PIN = 30
AUTH_EXT_MODE_CARD_FINGERPRINT_FACE = 31
AUTH_EXT_MODE_CARD_FINGERPRINT_PIN = 32
AUTH_EXT_MODE_CARD_FACE_OR_FINGERPRINT_PIN = 33
AUTH_EXT_MODE_CARD_FACE_FINGERPRINT_OR_PIN = 34
AUTH_EXT_MODE_CARD_FINGERPRINT_FACE_OR_PIN = 35
AUTH_EXT_MODE_ID_FACE = 36
AUTH_EXT_MODE_ID_FINGERPRINT = 37
AUTH_EXT_MODE_ID_PIN = 38
AUTH_EXT_MODE_ID_FACE_OR_FINGERPRINT = 39
AUTH_EXT_MODE_ID_FACE_OR_PIN = 40
AUTH_EXT_MODE_ID_FINGERPRINT_OR_PIN = 41
AUTH_EXT_MODE_ID_FACE_OR_FINGERPRINT_OR_PIN = 42
AUTH_EXT_MODE_ID_FACE_FINGERPRINT = 43
AUTH_EXT_MODE_ID_FACE_PIN = 44
AUTH_EXT_MODE_ID_FINGERPRINT_FACE = 45
AUTH_EXT_MODE_ID_FINGERPRINT_PIN = 46
AUTH_EXT_MODE_ID_FACE_OR_FINGERPRINT_PIN = 47
AUTH_EXT_MODE_ID_FACE_FINGERPRINT_OR_PIN = 48
AUTH_EXT_MODE_ID_FINGERPRINT_FACE_OR_PIN = 49
OPERATOR_LEVEL_NONE = 0
OPERATOR_LEVEL_ADMIN = 1
OPERATOR_LEVEL_CONFIG = 2
OPERATOR_LEVEL_USER = 3
FACE_DETECTION_NONE = 0
FACE_DETECTION_NORMAL = 1
FACE_DETECTION_STRICT = 2
GLOBAL_APB_FAIL_ACTION_NONE = 0
GLOBAL_APB_FAIL_ACTION_SOFT = 1
GLOBAL_APB_FAIL_ACTION_HARD = 2



_OPERATOR = _descriptor.Descriptor(
  name='Operator',
  full_name='auth.Operator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userID', full_name='auth.Operator.userID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level', full_name='auth.Operator.level', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31,
  serialized_end=93,
)


_AUTHSCHEDULE = _descriptor.Descriptor(
  name='AuthSchedule',
  full_name='auth.AuthSchedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='auth.AuthSchedule.mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scheduleID', full_name='auth.AuthSchedule.scheduleID', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=159,
)


_AUTHCONFIG = _descriptor.Descriptor(
  name='AuthConfig',
  full_name='auth.AuthConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='authSchedules', full_name='auth.AuthConfig.authSchedules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='useGlobalAPB', full_name='auth.AuthConfig.useGlobalAPB', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='globalAPBFailAction', full_name='auth.AuthConfig.globalAPBFailAction', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='useGroupMatching', full_name='auth.AuthConfig.useGroupMatching', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='usePrivateAuth', full_name='auth.AuthConfig.usePrivateAuth', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='faceDetectionLevel', full_name='auth.AuthConfig.faceDetectionLevel', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='useServerMatching', full_name='auth.AuthConfig.useServerMatching', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='useFullAccess', full_name='auth.AuthConfig.useFullAccess', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='matchTimeout', full_name='auth.AuthConfig.matchTimeout', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='authTimeout', full_name='auth.AuthConfig.authTimeout', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operators', full_name='auth.AuthConfig.operators', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=162,
  serialized_end=531,
)


_GETCONFIGREQUEST = _descriptor.Descriptor(
  name='GetConfigRequest',
  full_name='auth.GetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='auth.GetConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=533,
  serialized_end=569,
)


_GETCONFIGRESPONSE = _descriptor.Descriptor(
  name='GetConfigResponse',
  full_name='auth.GetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='auth.GetConfigResponse.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=571,
  serialized_end=624,
)


_SETCONFIGREQUEST = _descriptor.Descriptor(
  name='SetConfigRequest',
  full_name='auth.SetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='auth.SetConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='auth.SetConfigRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=626,
  serialized_end=696,
)


_SETCONFIGRESPONSE = _descriptor.Descriptor(
  name='SetConfigResponse',
  full_name='auth.SetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=698,
  serialized_end=717,
)


_SETCONFIGMULTIREQUEST = _descriptor.Descriptor(
  name='SetConfigMultiRequest',
  full_name='auth.SetConfigMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='auth.SetConfigMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='auth.SetConfigMultiRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=719,
  serialized_end=795,
)


_SETCONFIGMULTIRESPONSE = _descriptor.Descriptor(
  name='SetConfigMultiResponse',
  full_name='auth.SetConfigMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='auth.SetConfigMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=797,
  serialized_end=863,
)

_OPERATOR.fields_by_name['level'].enum_type = _OPERATORLEVEL
_AUTHSCHEDULE.fields_by_name['mode'].enum_type = _AUTHMODE
_AUTHCONFIG.fields_by_name['authSchedules'].message_type = _AUTHSCHEDULE
_AUTHCONFIG.fields_by_name['globalAPBFailAction'].enum_type = _GLOBALAPBFAILACTIONTYPE
_AUTHCONFIG.fields_by_name['faceDetectionLevel'].enum_type = _FACEDETECTIONLEVEL
_AUTHCONFIG.fields_by_name['operators'].message_type = _OPERATOR
_GETCONFIGRESPONSE.fields_by_name['config'].message_type = _AUTHCONFIG
_SETCONFIGREQUEST.fields_by_name['config'].message_type = _AUTHCONFIG
_SETCONFIGMULTIREQUEST.fields_by_name['config'].message_type = _AUTHCONFIG
_SETCONFIGMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
DESCRIPTOR.message_types_by_name['Operator'] = _OPERATOR
DESCRIPTOR.message_types_by_name['AuthSchedule'] = _AUTHSCHEDULE
DESCRIPTOR.message_types_by_name['AuthConfig'] = _AUTHCONFIG
DESCRIPTOR.message_types_by_name['GetConfigRequest'] = _GETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetConfigResponse'] = _GETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigRequest'] = _SETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetConfigResponse'] = _SETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigMultiRequest'] = _SETCONFIGMULTIREQUEST
DESCRIPTOR.message_types_by_name['SetConfigMultiResponse'] = _SETCONFIGMULTIRESPONSE
DESCRIPTOR.enum_types_by_name['AuthMode'] = _AUTHMODE
DESCRIPTOR.enum_types_by_name['OperatorLevel'] = _OPERATORLEVEL
DESCRIPTOR.enum_types_by_name['FaceDetectionLevel'] = _FACEDETECTIONLEVEL
DESCRIPTOR.enum_types_by_name['GlobalAPBFailActionType'] = _GLOBALAPBFAILACTIONTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Operator = _reflection.GeneratedProtocolMessageType('Operator', (_message.Message,), dict(
  DESCRIPTOR = _OPERATOR,
  __module__ = 'auth_pb2'
  # @@protoc_insertion_point(class_scope:auth.Operator)
  ))
_sym_db.RegisterMessage(Operator)

AuthSchedule = _reflection.GeneratedProtocolMessageType('AuthSchedule', (_message.Message,), dict(
  DESCRIPTOR = _AUTHSCHEDULE,
  __module__ = 'auth_pb2'
  # @@protoc_insertion_point(class_scope:auth.AuthSchedule)
  ))
_sym_db.RegisterMessage(AuthSchedule)

AuthConfig = _reflection.GeneratedProtocolMessageType('AuthConfig', (_message.Message,), dict(
  DESCRIPTOR = _AUTHCONFIG,
  __module__ = 'auth_pb2'
  # @@protoc_insertion_point(class_scope:auth.AuthConfig)
  ))
_sym_db.RegisterMessage(AuthConfig)

GetConfigRequest = _reflection.GeneratedProtocolMessageType('GetConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCONFIGREQUEST,
  __module__ = 'auth_pb2'
  # @@protoc_insertion_point(class_scope:auth.GetConfigRequest)
  ))
_sym_db.RegisterMessage(GetConfigRequest)

GetConfigResponse = _reflection.GeneratedProtocolMessageType('GetConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETCONFIGRESPONSE,
  __module__ = 'auth_pb2'
  # @@protoc_insertion_point(class_scope:auth.GetConfigResponse)
  ))
_sym_db.RegisterMessage(GetConfigResponse)

SetConfigRequest = _reflection.GeneratedProtocolMessageType('SetConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGREQUEST,
  __module__ = 'auth_pb2'
  # @@protoc_insertion_point(class_scope:auth.SetConfigRequest)
  ))
_sym_db.RegisterMessage(SetConfigRequest)

SetConfigResponse = _reflection.GeneratedProtocolMessageType('SetConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGRESPONSE,
  __module__ = 'auth_pb2'
  # @@protoc_insertion_point(class_scope:auth.SetConfigResponse)
  ))
_sym_db.RegisterMessage(SetConfigResponse)

SetConfigMultiRequest = _reflection.GeneratedProtocolMessageType('SetConfigMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGMULTIREQUEST,
  __module__ = 'auth_pb2'
  # @@protoc_insertion_point(class_scope:auth.SetConfigMultiRequest)
  ))
_sym_db.RegisterMessage(SetConfigMultiRequest)

SetConfigMultiResponse = _reflection.GeneratedProtocolMessageType('SetConfigMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGMULTIRESPONSE,
  __module__ = 'auth_pb2'
  # @@protoc_insertion_point(class_scope:auth.SetConfigMultiResponse)
  ))
_sym_db.RegisterMessage(SetConfigMultiResponse)


DESCRIPTOR._options = None

_AUTH = _descriptor.ServiceDescriptor(
  name='Auth',
  full_name='auth.Auth',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=3099,
  serialized_end=3306,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetConfig',
    full_name='auth.Auth.GetConfig',
    index=0,
    containing_service=None,
    input_type=_GETCONFIGREQUEST,
    output_type=_GETCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfig',
    full_name='auth.Auth.SetConfig',
    index=1,
    containing_service=None,
    input_type=_SETCONFIGREQUEST,
    output_type=_SETCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfigMulti',
    full_name='auth.Auth.SetConfigMulti',
    index=2,
    containing_service=None,
    input_type=_SETCONFIGMULTIREQUEST,
    output_type=_SETCONFIGMULTIRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_AUTH)

DESCRIPTOR.services_by_name['Auth'] = _AUTH

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tna.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biostarPython.service import err_pb2 as err__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tna.proto',
  package='tna',
  syntax='proto3',
  serialized_options=_b('\n\026com.supremainc.sdk.tnaP\001Z\023biostar/service/tna'),
  serialized_pb=_b('\n\ttna.proto\x12\x03tna\x1a\terr.proto\"r\n\tTNAConfig\x12\x17\n\x04mode\x18\x01 \x01(\x0e\x32\t.tna.Mode\x12\x15\n\x03key\x18\x02 \x01(\x0e\x32\x08.tna.Key\x12\x12\n\nisRequired\x18\x03 \x01(\x08\x12\x11\n\tschedules\x18\x04 \x03(\r\x12\x0e\n\x06labels\x18\x05 \x03(\t\"$\n\x10GetConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"3\n\x11GetConfigResponse\x12\x1e\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x0e.tna.TNAConfig\"D\n\x10SetConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x1e\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x0e.tna.TNAConfig\"\x13\n\x11SetConfigResponse\"J\n\x15SetConfigMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12\x1e\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x0e.tna.TNAConfig\"B\n\x16SetConfigMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"&\n\x07JobCode\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\r\n\x05label\x18\x02 \x01(\t\"\x87\x01\n\x06TNALog\x12\n\n\x02ID\x18\x01 \x01(\r\x12\x11\n\ttimestamp\x18\x02 \x01(\r\x12\x10\n\x08\x64\x65viceID\x18\x03 \x01(\r\x12\x0e\n\x06userID\x18\x04 \x01(\t\x12\x11\n\teventCode\x18\x05 \x01(\r\x12\x0f\n\x07subCode\x18\x06 \x01(\r\x12\x18\n\x06TNAKey\x18\x07 \x01(\x0e\x32\x08.tna.Key\"`\n\x0eTNAEventFilter\x12\x11\n\tstartTime\x18\x01 \x01(\r\x12\x0f\n\x07\x65ndTime\x18\x02 \x01(\r\x12\x0f\n\x07userIDs\x18\x03 \x03(\t\x12\x19\n\x07TNAKeys\x18\x04 \x03(\x0e\x32\x08.tna.Key\"\x82\x01\n\nJobCodeLog\x12\n\n\x02ID\x18\x01 \x01(\r\x12\x11\n\ttimestamp\x18\x02 \x01(\r\x12\x10\n\x08\x64\x65viceID\x18\x03 \x01(\r\x12\x0e\n\x06userID\x18\x04 \x01(\t\x12\x11\n\teventCode\x18\x05 \x01(\r\x12\x0f\n\x07subCode\x18\x06 \x01(\r\x12\x0f\n\x07jobCode\x18\x07 \x01(\r\"[\n\x12JobCodeEventFilter\x12\x11\n\tstartTime\x18\x01 \x01(\r\x12\x0f\n\x07\x65ndTime\x18\x02 \x01(\r\x12\x0f\n\x07userIDs\x18\x03 \x03(\t\x12\x10\n\x08jobCodes\x18\x04 \x03(\r\"t\n\x10GetTNALogRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x14\n\x0cstartEventID\x18\x02 \x01(\r\x12\x13\n\x0bmaxNumOfLog\x18\x03 \x01(\r\x12#\n\x06\x66ilter\x18\x04 \x01(\x0b\x32\x13.tna.TNAEventFilter\"3\n\x11GetTNALogResponse\x12\x1e\n\tTNAEvents\x18\x01 \x03(\x0b\x32\x0b.tna.TNALog\"S\n\x14GetJobCodeLogRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x14\n\x0cstartEventID\x18\x02 \x01(\r\x12\x13\n\x0bmaxNumOfLog\x18\x03 \x01(\r\"?\n\x15GetJobCodeLogResponse\x12&\n\rjobCodeEvents\x18\x01 \x03(\x0b\x32\x0f.tna.JobCodeLog*L\n\x04Mode\x12\n\n\x06UNUSED\x10\x00\x12\x0b\n\x07\x42Y_USER\x10\x01\x12\x0f\n\x0b\x42Y_SCHEDULE\x10\x02\x12\x0f\n\x0bLAST_CHOICE\x10\x03\x12\t\n\x05\x46IXED\x10\x04*\xcd\x01\n\x03Key\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\t\n\x05KEY_1\x10\x01\x12\t\n\x05KEY_2\x10\x02\x12\t\n\x05KEY_3\x10\x03\x12\t\n\x05KEY_4\x10\x04\x12\t\n\x05KEY_5\x10\x05\x12\t\n\x05KEY_6\x10\x06\x12\t\n\x05KEY_7\x10\x07\x12\t\n\x05KEY_8\x10\x08\x12\t\n\x05KEY_9\x10\t\x12\n\n\x06KEY_10\x10\n\x12\n\n\x06KEY_11\x10\x0b\x12\n\n\x06KEY_12\x10\x0c\x12\n\n\x06KEY_13\x10\r\x12\n\n\x06KEY_14\x10\x0e\x12\n\n\x06KEY_15\x10\x0f\x12\n\n\x06KEY_16\x10\x10\x32\xcc\x02\n\x03TNA\x12:\n\tGetConfig\x12\x15.tna.GetConfigRequest\x1a\x16.tna.GetConfigResponse\x12:\n\tSetConfig\x12\x15.tna.SetConfigRequest\x1a\x16.tna.SetConfigResponse\x12I\n\x0eSetConfigMulti\x12\x1a.tna.SetConfigMultiRequest\x1a\x1b.tna.SetConfigMultiResponse\x12:\n\tGetTNALog\x12\x15.tna.GetTNALogRequest\x1a\x16.tna.GetTNALogResponse\x12\x46\n\rGetJobCodeLog\x12\x19.tna.GetJobCodeLogRequest\x1a\x1a.tna.GetJobCodeLogResponseB/\n\x16\x63om.supremainc.sdk.tnaP\x01Z\x13\x62iostar/service/tnab\x06proto3')
  ,
  dependencies=[err__pb2.DESCRIPTOR,])

_MODE = _descriptor.EnumDescriptor(
  name='Mode',
  full_name='tna.Mode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNUSED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BY_USER', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BY_SCHEDULE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LAST_CHOICE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FIXED', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1294,
  serialized_end=1370,
)
_sym_db.RegisterEnumDescriptor(_MODE)

Mode = enum_type_wrapper.EnumTypeWrapper(_MODE)
_KEY = _descriptor.EnumDescriptor(
  name='Key',
  full_name='tna.Key',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_1', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_2', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_3', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_4', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_5', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_6', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_7', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_8', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_9', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_10', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_11', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_12', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_13', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_14', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_15', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_16', index=16, number=16,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1373,
  serialized_end=1578,
)
_sym_db.RegisterEnumDescriptor(_KEY)

Key = enum_type_wrapper.EnumTypeWrapper(_KEY)
UNUSED = 0
BY_USER = 1
BY_SCHEDULE = 2
LAST_CHOICE = 3
FIXED = 4
UNSPECIFIED = 0
KEY_1 = 1
KEY_2 = 2
KEY_3 = 3
KEY_4 = 4
KEY_5 = 5
KEY_6 = 6
KEY_7 = 7
KEY_8 = 8
KEY_9 = 9
KEY_10 = 10
KEY_11 = 11
KEY_12 = 12
KEY_13 = 13
KEY_14 = 14
KEY_15 = 15
KEY_16 = 16



_TNACONFIG = _descriptor.Descriptor(
  name='TNAConfig',
  full_name='tna.TNAConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='tna.TNAConfig.mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key', full_name='tna.TNAConfig.key', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isRequired', full_name='tna.TNAConfig.isRequired', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schedules', full_name='tna.TNAConfig.schedules', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labels', full_name='tna.TNAConfig.labels', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29,
  serialized_end=143,
)


_GETCONFIGREQUEST = _descriptor.Descriptor(
  name='GetConfigRequest',
  full_name='tna.GetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='tna.GetConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=145,
  serialized_end=181,
)


_GETCONFIGRESPONSE = _descriptor.Descriptor(
  name='GetConfigResponse',
  full_name='tna.GetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='tna.GetConfigResponse.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=183,
  serialized_end=234,
)


_SETCONFIGREQUEST = _descriptor.Descriptor(
  name='SetConfigRequest',
  full_name='tna.SetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='tna.SetConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='tna.SetConfigRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=236,
  serialized_end=304,
)


_SETCONFIGRESPONSE = _descriptor.Descriptor(
  name='SetConfigResponse',
  full_name='tna.SetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=306,
  serialized_end=325,
)


_SETCONFIGMULTIREQUEST = _descriptor.Descriptor(
  name='SetConfigMultiRequest',
  full_name='tna.SetConfigMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='tna.SetConfigMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='tna.SetConfigMultiRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=327,
  serialized_end=401,
)


_SETCONFIGMULTIRESPONSE = _descriptor.Descriptor(
  name='SetConfigMultiResponse',
  full_name='tna.SetConfigMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='tna.SetConfigMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=403,
  serialized_end=469,
)


_JOBCODE = _descriptor.Descriptor(
  name='JobCode',
  full_name='tna.JobCode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='tna.JobCode.code', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='tna.JobCode.label', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=471,
  serialized_end=509,
)


_TNALOG = _descriptor.Descriptor(
  name='TNALog',
  full_name='tna.TNALog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='tna.TNALog.ID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='tna.TNALog.timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='tna.TNALog.deviceID', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userID', full_name='tna.TNALog.userID', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eventCode', full_name='tna.TNALog.eventCode', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subCode', full_name='tna.TNALog.subCode', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='TNAKey', full_name='tna.TNALog.TNAKey', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=512,
  serialized_end=647,
)


_TNAEVENTFILTER = _descriptor.Descriptor(
  name='TNAEventFilter',
  full_name='tna.TNAEventFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='startTime', full_name='tna.TNAEventFilter.startTime', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endTime', full_name='tna.TNAEventFilter.endTime', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userIDs', full_name='tna.TNAEventFilter.userIDs', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='TNAKeys', full_name='tna.TNAEventFilter.TNAKeys', index=3,
      number=4, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=649,
  serialized_end=745,
)


_JOBCODELOG = _descriptor.Descriptor(
  name='JobCodeLog',
  full_name='tna.JobCodeLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='tna.JobCodeLog.ID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='tna.JobCodeLog.timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='tna.JobCodeLog.deviceID', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userID', full_name='tna.JobCodeLog.userID', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eventCode', full_name='tna.JobCodeLog.eventCode', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subCode', full_name='tna.JobCodeLog.subCode', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='jobCode', full_name='tna.JobCodeLog.jobCode', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=748,
  serialized_end=878,
)


_JOBCODEEVENTFILTER = _descriptor.Descriptor(
  name='JobCodeEventFilter',
  full_name='tna.JobCodeEventFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='startTime', full_name='tna.JobCodeEventFilter.startTime', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endTime', full_name='tna.JobCodeEventFilter.endTime', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userIDs', full_name='tna.JobCodeEventFilter.userIDs', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='jobCodes', full_name='tna.JobCodeEventFilter.jobCodes', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=880,
  serialized_end=971,
)


_GETTNALOGREQUEST = _descriptor.Descriptor(
  name='GetTNALogRequest',
  full_name='tna.GetTNALogRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='tna.GetTNALogRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='startEventID', full_name='tna.GetTNALogRequest.startEventID', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxNumOfLog', full_name='tna.GetTNALogRequest.maxNumOfLog', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter', full_name='tna.GetTNALogRequest.filter', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=973,
  serialized_end=1089,
)


_GETTNALOGRESPONSE = _descriptor.Descriptor(
  name='GetTNALogResponse',
  full_name='tna.GetTNALogResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='TNAEvents', full_name='tna.GetTNALogResponse.TNAEvents', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1091,
  serialized_end=1142,
)


_GETJOBCODELOGREQUEST = _descriptor.Descriptor(
  name='GetJobCodeLogRequest',
  full_name='tna.GetJobCodeLogRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='tna.GetJobCodeLogRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='startEventID', full_name='tna.GetJobCodeLogRequest.startEventID', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxNumOfLog', full_name='tna.GetJobCodeLogRequest.maxNumOfLog', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1144,
  serialized_end=1227,
)


_GETJOBCODELOGRESPONSE = _descriptor.Descriptor(
  name='GetJobCodeLogResponse',
  full_name='tna.GetJobCodeLogResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobCodeEvents', full_name='tna.GetJobCodeLogResponse.jobCodeEvents', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1229,
  serialized_end=1292,
)

_TNACONFIG.fields_by_name['mode'].enum_type = _MODE
_TNACONFIG.fields_by_name['key'].enum_type = _KEY
_GETCONFIGRESPONSE.fields_by_name['config'].message_type = _TNACONFIG
_SETCONFIGREQUEST.fields_by_name['config'].message_type = _TNACONFIG
_SETCONFIGMULTIREQUEST.fields_by_name['config'].message_type = _TNACONFIG
_SETCONFIGMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_TNALOG.fields_by_name['TNAKey'].enum_type = _KEY
_TNAEVENTFILTER.fields_by_name['TNAKeys'].enum_type = _KEY
_GETTNALOGREQUEST.fields_by_name['filter'].message_type = _TNAEVENTFILTER
_GETTNALOGRESPONSE.fields_by_name['TNAEvents'].message_type = _TNALOG
_GETJOBCODELOGRESPONSE.fields_by_name['jobCodeEvents'].message_type = _JOBCODELOG
DESCRIPTOR.message_types_by_name['TNAConfig'] = _TNACONFIG
DESCRIPTOR.message_types_by_name['GetConfigRequest'] = _GETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetConfigResponse'] = _GETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigRequest'] = _SETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetConfigResponse'] = _SETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigMultiRequest'] = _SETCONFIGMULTIREQUEST
DESCRIPTOR.message_types_by_name['SetConfigMultiResponse'] = _SETCONFIGMULTIRESPONSE
DESCRIPTOR.message_types_by_name['JobCode'] = _JOBCODE
DESCRIPTOR.message_types_by_name['TNALog'] = _TNALOG
DESCRIPTOR.message_types_by_name['TNAEventFilter'] = _TNAEVENTFILTER
DESCRIPTOR.message_types_by_name['JobCodeLog'] = _JOBCODELOG
DESCRIPTOR.message_types_by_name['JobCodeEventFilter'] = _JOBCODEEVENTFILTER
DESCRIPTOR.message_types_by_name['GetTNALogRequest'] = _GETTNALOGREQUEST
DESCRIPTOR.message_types_by_name['GetTNALogResponse'] = _GETTNALOGRESPONSE
DESCRIPTOR.message_types_by_name['GetJobCodeLogRequest'] = _GETJOBCODELOGREQUEST
DESCRIPTOR.message_types_by_name['GetJobCodeLogResponse'] = _GETJOBCODELOGRESPONSE
DESCRIPTOR.enum_types_by_name['Mode'] = _MODE
DESCRIPTOR.enum_types_by_name['Key'] = _KEY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TNAConfig = _reflection.GeneratedProtocolMessageType('TNAConfig', (_message.Message,), dict(
  DESCRIPTOR = _TNACONFIG,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.TNAConfig)
  ))
_sym_db.RegisterMessage(TNAConfig)

GetConfigRequest = _reflection.GeneratedProtocolMessageType('GetConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCONFIGREQUEST,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.GetConfigRequest)
  ))
_sym_db.RegisterMessage(GetConfigRequest)

GetConfigResponse = _reflection.GeneratedProtocolMessageType('GetConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETCONFIGRESPONSE,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.GetConfigResponse)
  ))
_sym_db.RegisterMessage(GetConfigResponse)

SetConfigRequest = _reflection.GeneratedProtocolMessageType('SetConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGREQUEST,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.SetConfigRequest)
  ))
_sym_db.RegisterMessage(SetConfigRequest)

SetConfigResponse = _reflection.GeneratedProtocolMessageType('SetConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGRESPONSE,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.SetConfigResponse)
  ))
_sym_db.RegisterMessage(SetConfigResponse)

SetConfigMultiRequest = _reflection.GeneratedProtocolMessageType('SetConfigMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGMULTIREQUEST,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.SetConfigMultiRequest)
  ))
_sym_db.RegisterMessage(SetConfigMultiRequest)

SetConfigMultiResponse = _reflection.GeneratedProtocolMessageType('SetConfigMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGMULTIRESPONSE,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.SetConfigMultiResponse)
  ))
_sym_db.RegisterMessage(SetConfigMultiResponse)

JobCode = _reflection.GeneratedProtocolMessageType('JobCode', (_message.Message,), dict(
  DESCRIPTOR = _JOBCODE,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.JobCode)
  ))
_sym_db.RegisterMessage(JobCode)

TNALog = _reflection.GeneratedProtocolMessageType('TNALog', (_message.Message,), dict(
  DESCRIPTOR = _TNALOG,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.TNALog)
  ))
_sym_db.RegisterMessage(TNALog)

TNAEventFilter = _reflection.GeneratedProtocolMessageType('TNAEventFilter', (_message.Message,), dict(
  DESCRIPTOR = _TNAEVENTFILTER,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.TNAEventFilter)
  ))
_sym_db.RegisterMessage(TNAEventFilter)

JobCodeLog = _reflection.GeneratedProtocolMessageType('JobCodeLog', (_message.Message,), dict(
  DESCRIPTOR = _JOBCODELOG,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.JobCodeLog)
  ))
_sym_db.RegisterMessage(JobCodeLog)

JobCodeEventFilter = _reflection.GeneratedProtocolMessageType('JobCodeEventFilter', (_message.Message,), dict(
  DESCRIPTOR = _JOBCODEEVENTFILTER,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.JobCodeEventFilter)
  ))
_sym_db.RegisterMessage(JobCodeEventFilter)

GetTNALogRequest = _reflection.GeneratedProtocolMessageType('GetTNALogRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETTNALOGREQUEST,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.GetTNALogRequest)
  ))
_sym_db.RegisterMessage(GetTNALogRequest)

GetTNALogResponse = _reflection.GeneratedProtocolMessageType('GetTNALogResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETTNALOGRESPONSE,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.GetTNALogResponse)
  ))
_sym_db.RegisterMessage(GetTNALogResponse)

GetJobCodeLogRequest = _reflection.GeneratedProtocolMessageType('GetJobCodeLogRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETJOBCODELOGREQUEST,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.GetJobCodeLogRequest)
  ))
_sym_db.RegisterMessage(GetJobCodeLogRequest)

GetJobCodeLogResponse = _reflection.GeneratedProtocolMessageType('GetJobCodeLogResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETJOBCODELOGRESPONSE,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.GetJobCodeLogResponse)
  ))
_sym_db.RegisterMessage(GetJobCodeLogResponse)


DESCRIPTOR._options = None

_TNA = _descriptor.ServiceDescriptor(
  name='TNA',
  full_name='tna.TNA',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1581,
  serialized_end=1913,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetConfig',
    full_name='tna.TNA.GetConfig',
    index=0,
    containing_service=None,
    input_type=_GETCONFIGREQUEST,
    output_type=_GETCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfig',
    full_name='tna.TNA.SetConfig',
    index=1,
    containing_service=None,
    input_type=_SETCONFIGREQUEST,
    output_type=_SETCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfigMulti',
    full_name='tna.TNA.SetConfigMulti',
    index=2,
    containing_service=None,
    input_type=_SETCONFIGMULTIREQUEST,
    output_type=_SETCONFIGMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetTNALog',
    full_name='tna.TNA.GetTNALog',
    index=3,
    containing_service=None,
    input_type=_GETTNALOGREQUEST,
    output_type=_GETTNALOGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetJobCodeLog',
    full_name='tna.TNA.GetJobCodeLog',
    index=4,
    containing_service=None,
    input_type=_GETJOBCODELOGREQUEST,
    output_type=_GETJOBCODELOGRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_TNA)

DESCRIPTOR.services_by_name['TNA'] = _TNA

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from biostarPython.service import user_pb2 as user__pb2


class UserStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetList = channel.unary_unary(
        '/user.User/GetList',
        request_serializer=user__pb2.GetListRequest.SerializeToString,
        response_deserializer=user__pb2.GetListResponse.FromString,
        )
    self.Get = channel.unary_unary(
        '/user.User/Get',
        request_serializer=user__pb2.GetRequest.SerializeToString,
        response_deserializer=user__pb2.GetResponse.FromString,
        )
    self.GetPartial = channel.unary_unary(
        '/user.User/GetPartial',
        request_serializer=user__pb2.GetPartialRequest.SerializeToString,
        response_deserializer=user__pb2.GetPartialResponse.FromString,
        )
    self.Enroll = channel.unary_unary(
        '/user.User/Enroll',
        request_serializer=user__pb2.EnrollRequest.SerializeToString,
        response_deserializer=user__pb2.EnrollResponse.FromString,
        )
    self.EnrollMulti = channel.unary_unary(
        '/user.User/EnrollMulti',
        request_serializer=user__pb2.EnrollMultiRequest.SerializeToString,
        response_deserializer=user__pb2.EnrollMultiResponse.FromString,
        )
    self.Delete = channel.unary_unary(
        '/user.User/Delete',
        request_serializer=user__pb2.DeleteRequest.SerializeToString,
        response_deserializer=user__pb2.DeleteResponse.FromString,
        )
    self.DeleteMulti = channel.unary_unary(
        '/user.User/DeleteMulti',
        request_serializer=user__pb2.DeleteMultiRequest.SerializeToString,
        response_deserializer=user__pb2.DeleteMultiResponse.FromString,
        )
    self.DeleteAll = channel.unary_unary(
        '/user.User/DeleteAll',
        request_serializer=user__pb2.DeleteAllRequest.SerializeToString,
        response_deserializer=user__pb2.DeleteAllResponse.FromString,
        )
    self.DeleteAllMulti = channel.unary_unary(
        '/user.User/DeleteAllMulti',
        request_serializer=user__pb2.DeleteAllMultiRequest.SerializeToString,
        response_deserializer=user__pb2.DeleteAllMultiResponse.FromString,
        )
    self.GetCard = channel.unary_unary(
        '/user.User/GetCard',
        request_serializer=user__pb2.GetCardRequest.SerializeToString,
        response_deserializer=user__pb2.GetCardResponse.FromString,
        )
    self.SetCard = channel.unary_unary(
        '/user.User/SetCard',
        request_serializer=user__pb2.SetCardRequest.SerializeToString,
        response_deserializer=user__pb2.SetCardResponse.FromString,
        )
    self.SetCardMulti = channel.unary_unary(
        '/user.User/SetCardMulti',
        request_serializer=user__pb2.SetCardMultiRequest.SerializeToString,
        response_deserializer=user__pb2.SetCardMultiResponse.FromString,
        )
    self.GetFinger = channel.unary_unary(
        '/user.User/GetFinger',
        request_serializer=user__pb2.GetFingerRequest.SerializeToString,
        response_deserializer=user__pb2.GetFingerResponse.FromString,
        )
    self.SetFinger = channel.unary_unary(
        '/user.User/SetFinger',
        request_serializer=user__pb2.SetFingerRequest.SerializeToString,
        response_deserializer=user__pb2.SetFingerResponse.FromString,
        )
    self.SetFingerMulti = channel.unary_unary(
        '/user.User/SetFingerMulti',
        request_serializer=user__pb2.SetFingerMultiRequest.SerializeToString,
        response_deserializer=user__pb2.SetFingerMultiResponse.FromString,
        )
    self.GetFace = channel.unary_unary(
        '/user.User/GetFace',
        request_serializer=user__pb2.GetFaceRequest.SerializeToString,
        response_deserializer=user__pb2.GetFaceResponse.FromString,
        )
    self.SetFace = channel.unary_unary(
        '/user.User/SetFace',
        request_serializer=user__pb2.SetFaceRequest.SerializeToString,
        response_deserializer=user__pb2.SetFaceResponse.FromString,
        )
    self.SetFaceMulti = channel.unary_unary(
        '/user.User/SetFaceMulti',
        request_serializer=user__pb2.SetFaceMultiRequest.SerializeToString,
        response_deserializer=user__pb2.SetFaceMultiResponse.FromString,
        )
    self.GetAccessGroup = channel.unary_unary(
        '/user.User/GetAccessGroup',
        request_serializer=user__pb2.GetAccessGroupRequest.SerializeToString,
        response_deserializer=user__pb2.GetAccessGroupResponse.FromString,
        )
    self.SetAccessGroup = channel.unary_unary(
        '/user.User/SetAccessGroup',
        request_serializer=user__pb2.SetAccessGroupRequest.SerializeToString,
        response_deserializer=user__pb2.SetAccessGroupResponse.FromString,
        )
    self.SetAccessGroupMulti = channel.unary_unary(
        '/user.User/SetAccessGroupMulti',
        request_serializer=user__pb2.SetAccessGroupMultiRequest.SerializeToString,
        response_deserializer=user__pb2.SetAccessGroupMultiResponse.FromString,
        )
    self.GetJobCode = channel.unary_unary(
        '/user.User/GetJobCode',
        request_serializer=user__pb2.GetJobCodeRequest.SerializeToString,
        response_deserializer=user__pb2.GetJobCodeResponse.FromString,
        )
    self.SetJobCode = channel.unary_unary(
        '/user.User/SetJobCode',
        request_serializer=user__pb2.SetJobCodeRequest.SerializeToString,
        response_deserializer=user__pb2.SetJobCodeResponse.FromString,
        )
    self.SetJobCodeMulti = channel.unary_unary(
        '/user.User/SetJobCodeMulti',
        request_serializer=user__pb2.SetJobCodeMultiRequest.SerializeToString,
        response_deserializer=user__pb2.SetJobCodeMultiResponse.FromString,
        )
    self.GetPINHash = channel.unary_unary(
        '/user.User/GetPINHash',
        request_serializer=user__pb2.GetPINHashRequest.SerializeToString,
        response_deserializer=user__pb2.GetPINHashResponse.FromString,
        )


class UserServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def GetList(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Get(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetPartial(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Enroll(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EnrollMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteAll(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteAllMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetCard(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetCard(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetCardMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetFinger(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetFinger(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetFingerMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetFace(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetFace(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetFaceMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetAccessGroup(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetAccessGroup(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetAccessGroupMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetJobCode(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetJobCode(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetJobCodeMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetPINHash(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_UserServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetList': grpc.unary_unary_rpc_method_handler(
          servicer.GetList,
          request_deserializer=user__pb2.GetListRequest.FromString,
          response_serializer=user__pb2.GetListResponse.SerializeToString,
      ),
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=user__pb2.GetRequest.FromString,
          response_serializer=user__pb2.GetResponse.SerializeToString,
      ),
      'GetPartial': grpc.unary_unary_rpc_method_handler(
          servicer.GetPartial,
          request_deserializer=user__pb2.GetPartialRequest.FromString,
          response_serializer=user__pb2.GetPartialResponse.SerializeToString,
      ),
      'Enroll': grpc.unary_unary_rpc_method_handler(
          servicer.Enroll,
          request_deserializer=user__pb2.EnrollRequest.FromString,
          response_serializer=user__pb2.EnrollResponse.SerializeToString,
      ),
      'EnrollMulti': grpc.unary_unary_rpc_method_handler(
          servicer.EnrollMulti,
          request_deserializer=user__pb2.EnrollMultiRequest.FromString,
          response_serializer=user__pb2.EnrollMultiResponse.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=user__pb2.DeleteRequest.FromString,
          response_serializer=user__pb2.DeleteResponse.SerializeToString,
      ),
      'DeleteMulti': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteMulti,
          request_deserializer=user__pb2.DeleteMultiRequest.FromString,
          response_serializer=user__pb2.DeleteMultiResponse.SerializeToString,
      ),
      'DeleteAll': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteAll,
          request_deserializer=user__pb2.DeleteAllRequest.FromString,
          response_serializer=user__pb2.DeleteAllResponse.SerializeToString,
      ),
      'DeleteAllMulti': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteAllMulti,
          request_deserializer=user__pb2.DeleteAllMultiRequest.FromString,
          response_serializer=user__pb2.DeleteAllMultiResponse.SerializeToString,
      ),
      'GetCard': grpc.unary_unary_rpc_method_handler(
          servicer.GetCard,
          request_deserializer=user__pb2.GetCardRequest.FromString,
          response_serializer=user__pb2.GetCardResponse.SerializeToString,
      ),
      'SetCard': grpc.unary_unary_rpc_method_handler(
          servicer.SetCard,
          request_deserializer=user__pb2.SetCardRequest.FromString,
          response_serializer=user__pb2.SetCardResponse.SerializeToString,
      ),
      'SetCardMulti': grpc.unary_unary_rpc_method_handler(
          servicer.SetCardMulti,
          request_deserializer=user__pb2.SetCardMultiRequest.FromString,
          response_serializer=user__pb2.SetCardMultiResponse.SerializeToString,
      ),
      'GetFinger': grpc.unary_unary_rpc_method_handler(
          servicer.GetFinger,
          request_deserializer=user__pb2.GetFingerRequest.FromString,
          response_serializer=user__pb2.GetFingerResponse.SerializeToString,
      ),
      'SetFinger': grpc.unary_unary_rpc_method_handler(
          servicer.SetFinger,
          request_deserializer=user__pb2.SetFingerRequest.FromString,
          response_serializer=user__pb2.SetFingerResponse.SerializeToString,
      ),
      'SetFingerMulti': grpc.unary_unary_rpc_method_handler(
          servicer.SetFingerMulti,
          request_deserializer=user__pb2.SetFingerMultiRequest.FromString,
          response_serializer=user__pb2.SetFingerMultiResponse.SerializeToString,
      ),
      'GetFace': grpc.unary_unary_rpc_method_handler(
          servicer.GetFace,
          request_deserializer=user__pb2.GetFaceRequest.FromString,
          response_serializer=user__pb2.GetFaceResponse.SerializeToString,
      ),
      'SetFace': grpc.unary_unary_rpc_method_handler(
          servicer.SetFace,
          request_deserializer=user__pb2.SetFaceRequest.FromString,
          response_serializer=user__pb2.SetFaceResponse.SerializeToString,
      ),
      'SetFaceMulti': grpc.unary_unary_rpc_method_handler(
          servicer.SetFaceMulti,
          request_deserializer=user__pb2.SetFaceMultiRequest.FromString,
          response_serializer=user__pb2.SetFaceMultiResponse.SerializeToString,
      ),
      'GetAccessGroup': grpc.unary_unary_rpc_method_handler(
          servicer.GetAccessGroup,
          request_deserializer=user__pb2.GetAccessGroupRequest.FromString,
          response_serializer=user__pb2.GetAccessGroupResponse.SerializeToString,
      ),
      'SetAccessGroup': grpc.unary_unary_rpc_method_handler(
          servicer.SetAccessGroup,
          request_deserializer=user__pb2.SetAccessGroupRequest.FromString,
          response_serializer=user__pb2.SetAccessGroupResponse.SerializeToString,
      ),
      'SetAccessGroupMulti': grpc.unary_unary_rpc_method_handler(
          servicer.SetAccessGroupMulti,
          request_deserializer=user__pb2.SetAccessGroupMultiRequest.FromString,
          response_serializer=user__pb2.SetAccessGroupMultiResponse.SerializeToString,
      ),
      'GetJobCode': grpc.unary_unary_rpc_method_handler(
          servicer.GetJobCode,
          request_deserializer=user__pb2.GetJobCodeRequest.FromString,
          response_serializer=user__pb2.GetJobCodeResponse.SerializeToString,
      ),
      'SetJobCode': grpc.unary_unary_rpc_method_handler(
          servicer.SetJobCode,
          request_deserializer=user__pb2.SetJobCodeRequest.FromString,
          response_serializer=user__pb2.SetJobCodeResponse.SerializeToString,
      ),
      'SetJobCodeMulti': grpc.unary_unary_rpc_method_handler(
          servicer.SetJobCodeMulti,
          request_deserializer=user__pb2.SetJobCodeMultiRequest.FromString,
          response_serializer=user__pb2.SetJobCodeMultiResponse.SerializeToString,
      ),
      'GetPINHash': grpc.unary_unary_rpc_method_handler(
          servicer.GetPINHash,
          request_deserializer=user__pb2.GetPINHashRequest.FromString,
          response_serializer=user__pb2.GetPINHashResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'user.User', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: status.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biostarPython.service import action_pb2 as action__pb2
from biostarPython.service import err_pb2 as err__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='status.proto',
  package='status',
  syntax='proto3',
  serialized_options=_b('\n\031com.supremainc.sdk.statusP\001Z\026biostar/service/status'),
  serialized_pb=_b('\n\x0cstatus.proto\x12\x06status\x1a\x0c\x61\x63tion.proto\x1a\terr.proto\"j\n\tLEDStatus\x12*\n\x0c\x64\x65viceStatus\x18\x01 \x01(\x0e\x32\x14.status.DeviceStatus\x12\r\n\x05\x63ount\x18\x02 \x01(\r\x12\"\n\x07signals\x18\x03 \x03(\x0b\x32\x11.action.LEDSignal\"p\n\x0c\x42uzzerStatus\x12*\n\x0c\x64\x65viceStatus\x18\x01 \x01(\x0e\x32\x14.status.DeviceStatus\x12\r\n\x05\x63ount\x18\x02 \x01(\r\x12%\n\x07signals\x18\x03 \x03(\x0b\x32\x14.action.BuzzerSignal\"^\n\x0cStatusConfig\x12#\n\x08LEDState\x18\x01 \x03(\x0b\x32\x11.status.LEDStatus\x12)\n\x0b\x42uzzerState\x18\x02 \x03(\x0b\x32\x14.status.BuzzerStatus\"$\n\x10GetConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"9\n\x11GetConfigResponse\x12$\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x14.status.StatusConfig\"J\n\x10SetConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12$\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x14.status.StatusConfig\"\x13\n\x11SetConfigResponse\"P\n\x15SetConfigMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12$\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x14.status.StatusConfig\"B\n\x16SetConfigMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse*\xce\x03\n\x0c\x44\x65viceStatus\x12\x18\n\x14\x44\x45VICE_STATUS_NORMAL\x10\x00\x12\x18\n\x14\x44\x45VICE_STATUS_LOCKED\x10\x01\x12\x1b\n\x17\x44\x45VICE_STATUS_RTC_ERROR\x10\x02\x12\x1f\n\x1b\x44\x45VICE_STATUS_WAITING_INPUT\x10\x03\x12\x1e\n\x1a\x44\x45VICE_STATUS_WAITING_DHCP\x10\x04\x12\x1d\n\x19\x44\x45VICE_STATUS_SCAN_FINGER\x10\x05\x12\x1b\n\x17\x44\x45VICE_STATUS_SCAN_CARD\x10\x06\x12\x19\n\x15\x44\x45VICE_STATUS_SUCCESS\x10\x07\x12\x16\n\x12\x44\x45VICE_STATUS_FAIL\x10\x08\x12\x18\n\x14\x44\x45VICE_STATUS_DURESS\x10\t\x12%\n!DEVICE_STATUS_PROCESS_CONFIG_CARD\x10\n\x12%\n!DEVICE_STATUS_SUCCESS_CONFIG_CARD\x10\x0b\x12\x1b\n\x17\x44\x45VICE_STATUS_SCAN_FACE\x10\x0c\x12\x1b\n\x17\x44\x45VICE_STATUS_RESERVED3\x10\r\x12\x1b\n\x17\x44\x45VICE_STATUS_RESERVED4\x10\x0e\x32\xdd\x01\n\x06Status\x12@\n\tGetConfig\x12\x18.status.GetConfigRequest\x1a\x19.status.GetConfigResponse\x12@\n\tSetConfig\x12\x18.status.SetConfigRequest\x1a\x19.status.SetConfigResponse\x12O\n\x0eSetConfigMulti\x12\x1d.status.SetConfigMultiRequest\x1a\x1e.status.SetConfigMultiResponseB5\n\x19\x63om.supremainc.sdk.statusP\x01Z\x16\x62iostar/service/statusb\x06proto3')
  ,
  dependencies=[action__pb2.DESCRIPTOR,err__pb2.DESCRIPTOR,])

_DEVICESTATUS = _descriptor.EnumDescriptor(
  name='DeviceStatus',
  full_name='status.DeviceStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEVICE_STATUS_NORMAL', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_STATUS_LOCKED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_STATUS_RTC_ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_STATUS_WAITING_INPUT', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_STATUS_WAITING_DHCP', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_STATUS_SCAN_FINGER', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_STATUS_SCAN_CARD', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_STATUS_SUCCESS', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_STATUS_FAIL', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_STATUS_DURESS', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_STATUS_PROCESS_CONFIG_CARD', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_STATUS_SUCCESS_CONFIG_CARD', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_STATUS_SCAN_FACE', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_STATUS_RESERVED3', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_STATUS_RESERVED4', index=14, number=14,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=712,
  serialized_end=1174,
)
_sym_db.RegisterEnumDescriptor(_DEVICESTATUS)

DeviceStatus = enum_type_wrapper.EnumTypeWrapper(_DEVICESTATUS)
DEVICE_STATUS_NORMAL = 0
DEVICE_STATUS_LOCKED = 1
DEVICE_STATUS_RTC_ERROR = 2
DEVICE_STATUS_WAITING_INPUT = 3
DEVICE_STATUS_WAITING_DHCP = 4
DEVICE_STATUS_SCAN_FINGER = 5
DEVICE_STATUS_SCAN_CARD = 6
DEVICE_STATUS_SUCCESS = 7
DEVICE_STATUS_FAIL = 8
DEVICE_STATUS_DURESS = 9
DEVICE_STATUS_PROCESS_CONFIG_CARD = 10
DEVICE_STATUS_SUCCESS_CONFIG_CARD = 11
DEVICE_STATUS_SCAN_FACE = 12
DEVICE_STATUS_RESERVED3 = 13
DEVICE_STATUS_RESERVED4 = 14



_LEDSTATUS = _descriptor.Descriptor(
  name='LEDStatus',
  full_name='status.LEDStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceStatus', full_name='status.LEDStatus.deviceStatus', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='status.LEDStatus.count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signals', full_name='status.LEDStatus.signals', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49,
  serialized_end=155,
)


_BUZZERSTATUS = _descriptor.Descriptor(
  name='BuzzerStatus',
  full_name='status.BuzzerStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceStatus', full_name='status.BuzzerStatus.deviceStatus', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='status.BuzzerStatus.count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signals', full_name='status.BuzzerStatus.signals', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=157,
  serialized_end=269,
)


_STATUSCONFIG = _descriptor.Descriptor(
  name='StatusConfig',
  full_name='status.StatusConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='LEDState', full_name='status.StatusConfig.LEDState', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='BuzzerState', full_name='status.StatusConfig.BuzzerState', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=271,
  serialized_end=365,
)


_GETCONFIGREQUEST = _descriptor.Descriptor(
  name='GetConfigRequest',
  full_name='status.GetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='status.GetConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=367,
  serialized_end=403,
)


_GETCONFIGRESPONSE = _descriptor.Descriptor(
  name='GetConfigResponse',
  full_name='status.GetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='status.GetConfigResponse.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=405,
  serialized_end=462,
)


_SETCONFIGREQUEST = _descriptor.Descriptor(
  name='SetConfigRequest',
  full_name='status.SetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='status.SetConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='status.SetConfigRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=464,
  serialized_end=538,
)


_SETCONFIGRESPONSE = _descriptor.Descriptor(
  name='SetConfigResponse',
  full_name='status.SetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=540,
  serialized_end=559,
)


_SETCONFIGMULTIREQUEST = _descriptor.Descriptor(
  name='SetConfigMultiRequest',
  full_name='status.SetConfigMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='status.SetConfigMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='status.SetConfigMultiRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=561,
  serialized_end=641,
)


_SETCONFIGMULTIRESPONSE = _descriptor.Descriptor(
  name='SetConfigMultiResponse',
  full_name='status.SetConfigMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='status.SetConfigMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=643,
  serialized_end=709,
)

_LEDSTATUS.fields_by_name['deviceStatus'].enum_type = _DEVICESTATUS
_LEDSTATUS.fields_by_name['signals'].message_type = action__pb2._LEDSIGNAL
_BUZZERSTATUS.fields_by_name['deviceStatus'].enum_type = _DEVICESTATUS
_BUZZERSTATUS.fields_by_name['signals'].message_type = action__pb2._BUZZERSIGNAL
_STATUSCONFIG.fields_by_name['LEDState'].message_type = _LEDSTATUS
_STATUSCONFIG.fields_by_name['BuzzerState'].message_type = _BUZZERSTATUS
_GETCONFIGRESPONSE.fields_by_name['config'].message_type = _STATUSCONFIG
_SETCONFIGREQUEST.fields_by_name['config'].message_type = _STATUSCONFIG
_SETCONFIGMULTIREQUEST.fields_by_name['config'].message_type = _STATUSCONFIG
_SETCONFIGMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
DESCRIPTOR.message_types_by_name['LEDStatus'] = _LEDSTATUS
DESCRIPTOR.message_types_by_name['BuzzerStatus'] = _BUZZERSTATUS
DESCRIPTOR.message_types_by_name['StatusConfig'] = _STATUSCONFIG
DESCRIPTOR.message_types_by_name['GetConfigRequest'] = _GETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetConfigResponse'] = _GETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigRequest'] = _SETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetConfigResponse'] = _SETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigMultiRequest'] = _SETCONFIGMULTIREQUEST
DESCRIPTOR.message_types_by_name['SetConfigMultiResponse'] = _SETCONFIGMULTIRESPONSE
DESCRIPTOR.enum_types_by_name['DeviceStatus'] = _DEVICESTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LEDStatus = _reflection.GeneratedProtocolMessageType('LEDStatus', (_message.Message,), dict(
  DESCRIPTOR = _LEDSTATUS,
  __module__ = 'status_pb2'
  # @@protoc_insertion_point(class_scope:status.LEDStatus)
  ))
_sym_db.RegisterMessage(LEDStatus)

BuzzerStatus = _reflection.GeneratedProtocolMessageType('BuzzerStatus', (_message.Message,), dict(
  DESCRIPTOR = _BUZZERSTATUS,
  __module__ = 'status_pb2'
  # @@protoc_insertion_point(class_scope:status.BuzzerStatus)
  ))
_sym_db.RegisterMessage(BuzzerStatus)

StatusConfig = _reflection.GeneratedProtocolMessageType('StatusConfig', (_message.Message,), dict(
  DESCRIPTOR = _STATUSCONFIG,
  __module__ = 'status_pb2'
  # @@protoc_insertion_point(class_scope:status.StatusConfig)
  ))
_sym_db.RegisterMessage(StatusConfig)

GetConfigRequest = _reflection.GeneratedProtocolMessageType('GetConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCONFIGREQUEST,
  __module__ = 'status_pb2'
  # @@protoc_insertion_point(class_scope:status.GetConfigRequest)
  ))
_sym_db.RegisterMessage(GetConfigRequest)

GetConfigResponse = _reflection.GeneratedProtocolMessageType('GetConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETCONFIGRESPONSE,
  __module__ = 'status_pb2'
  # @@protoc_insertion_point(class_scope:status.GetConfigResponse)
  ))
_sym_db.RegisterMessage(GetConfigResponse)

SetConfigRequest = _reflection.GeneratedProtocolMessageType('SetConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGREQUEST,
  __module__ = 'status_pb2'
  # @@protoc_insertion_point(class_scope:status.SetConfigRequest)
  ))
_sym_db.RegisterMessage(SetConfigRequest)

SetConfigResponse = _reflection.GeneratedProtocolMessageType('SetConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGRESPONSE,
  __module__ = 'status_pb2'
  # @@protoc_insertion_point(class_scope:status.SetConfigResponse)
  ))
_sym_db.RegisterMessage(SetConfigResponse)

SetConfigMultiRequest = _reflection.GeneratedProtocolMessageType('SetConfigMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGMULTIREQUEST,
  __module__ = 'status_pb2'
  # @@protoc_insertion_point(class_scope:status.SetConfigMultiRequest)
  ))
_sym_db.RegisterMessage(SetConfigMultiRequest)

SetConfigMultiResponse = _reflection.GeneratedProtocolMessageType('SetConfigMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGMULTIRESPONSE,
  __module__ = 'status_pb2'
  # @@protoc_insertion_point(class_scope:status.SetConfigMultiResponse)
  ))
_sym_db.RegisterMessage(SetConfigMultiResponse)


DESCRIPTOR._options = None

_STATUS = _descriptor.ServiceDescriptor(
  name='Status',
  full_name='status.Status',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1177,
  serialized_end=1398,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetConfig',
    full_name='status.Status.GetConfig',
    index=0,
    containing_service=None,
    input_type=_GETCONFIGREQUEST,
    output_type=_GETCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfig',
    full_name='status.Status.SetConfig',
    index=1,
    containing_service=None,
    input_type=_SETCONFIGREQUEST,
    output_type=_SETCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfigMulti',
    full_name='status.Status.SetConfigMulti',
    index=2,
    containing_service=None,
    input_type=_SETCONFIGMULTIREQUEST,
    output_type=_SETCONFIGMULTIRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_STATUS)

DESCRIPTOR.services_by_name['Status'] = _STATUS

# @@protoc_insertion_point(module_scope)
